from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field


# Shared properties
class TaskBase(BaseModel):
    title: str = Field(..., min_length=1, max_length=255, description="Task title")
    description: Optional[str] = Field(None, description="Task description")
    completed: Optional[bool] = Field(False, description="Task completion status")
    priority: Optional[int] = Field(1, ge=1, le=3, description="Task priority: 1-Low, 2-Medium, 3-High")
    due_date: Optional[datetime] = Field(None, description="Task due date")


# Properties to receive on task creation
class TaskCreate(TaskBase):
    pass


# Properties to receive on task update
class TaskUpdate(BaseModel):
    title: Optional[str] = Field(None, min_length=1, max_length=255, description="Task title")
    description: Optional[str] = Field(None, description="Task description")
    completed: Optional[bool] = Field(None, description="Task completion status")
    priority: Optional[int] = Field(None, ge=1, le=3, description="Task priority: 1-Low, 2-Medium, 3-High")
    due_date: Optional[datetime] = Field(None, description="Task due date")


# Properties shared by models stored in DB
class TaskInDBBase(TaskBase):
    id: int
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True


# Properties to return to client
class Task(TaskInDBBase):
    pass